@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.c,v 1.33 2006/08/07 18:04:07 pborelli Exp $
+ * $Id: gedit-window.c,v 1.35 2006/08/14 19:05:00 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -144,11 +144,9 @@ gedit_window_destroy (GtkObject *object)
 
 	window = GEDIT_WINDOW (object);
 
-	if (gedit_prefs_manager_window_height_can_set ())
-		gedit_prefs_manager_set_window_height (window->priv->height);
-
-	if (gedit_prefs_manager_window_width_can_set ())
-		gedit_prefs_manager_set_window_width (window->priv->width);
+	if (gedit_prefs_manager_window_size_can_set ())
+		gedit_prefs_manager_set_window_size (window->priv->width,
+						     window->priv->height);
 
 	if (gedit_prefs_manager_window_state_can_set ())
 		gedit_prefs_manager_set_window_state (window->priv->window_state);
@@ -1089,7 +1087,9 @@ update_recent_files_menu (GeditWindow *window)
 						 escaped);
 		g_free (escaped);
 
-		uri = gtk_recent_info_get_uri_display (info);
+		/* gtk_recent_info_get_uri_display (info) is buggy and
+		 * works only for local files */
+		uri = gedit_utils_format_uri_for_display (gtk_recent_info_get_uri (info));
 		trunc_uri = gedit_utils_str_middle_truncate (uri,
 							     TIP_MAX_URI_LEN);
 		g_free (uri);
@@ -1587,10 +1587,10 @@ clone_window (GeditWindow *origin)
 				     
 	if ((origin->priv->window_state & GDK_WINDOW_STATE_MAXIMIZED) != 0)
 	{
-		gtk_window_set_default_size (window, 
-					     gedit_prefs_manager_get_default_window_width (),
-					     gedit_prefs_manager_get_default_window_height ());
-					     
+		gint w, h;
+
+		gedit_prefs_manager_get_default_window_size (&w, &h);
+		gtk_window_set_default_size (window, w, h);
 		gtk_window_maximize (window);
 	}
 	else
